.. histlite documentation master file, created by
   sphinx-quickstart on Thu Mar 21 11:24:46 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to histlite!
====================

**histlite** is a histogram calculation and plotting library that is "lite"
on data structures but rich in statistics and visualization features.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   about
   install
   tutorials
   reference

